/**
 * @file CCMAttributes.cs 
 * Defines the attributes that are used in bisimulation verification: 
 * Event, Range, Property, Abstracts, Eq
 *
 * (C) 2004 Martin Pitt <martin@piware.de>
 *
 * This software is distributed under the terms and conditions of the GNU
 * General Public License (see file COPYING)
 */

using System;

/// Range attribute.
[AttributeUsage( AttributeTargets.Field | AttributeTargets.Parameter )]
public class RangeAttribute : Attribute {
    public RangeAttribute( int min, int max, int step ) {}
    public RangeAttribute( int min, int max ) {}
    public RangeAttribute( double min, double max, double step ) {}
    public RangeAttribute( double min, double max ) {}
}

/// Event attribute.
[AttributeUsage( AttributeTargets.Method )]
public class EventAttribute : Attribute {}

/// Property attribute.
[AttributeUsage( AttributeTargets.Field )]
public class PropertyAttribute : Attribute {
    public PropertyAttribute( string name ) {}
}

/// Abstracts attribute.
[AttributeUsage( AttributeTargets.Field )]
public class AbstractsAttribute : Attribute {
    public AbstractsAttribute( string name ) {}
}

/// Eq attribute.
[AttributeUsage( AttributeTargets.Field, AllowMultiple = true )]
public class EqAttribute : Attribute {
    public EqAttribute( int a, int i ) {}
    public EqAttribute( int a, double i ) {}
    public EqAttribute( int a, bool i ) {}
    public EqAttribute( int a, string i ) {}

    public EqAttribute( double a, int i ) {}
    public EqAttribute( double a, double i ) {}
    public EqAttribute( double a, bool i ) {}
    public EqAttribute( double a, string i ) {}

    public EqAttribute( bool a, int i ) {}
    public EqAttribute( bool a, double i ) {}
    public EqAttribute( bool a, bool i ) {}
    public EqAttribute( bool a, string i ) {}
}

