/**
 * @file bindump.cs 
 * Reads a binary process dump and outputs its CCMB representation.
 *
 * (C) 2004 Martin Pitt <martin@piware.de>
 *
 * This software is distributed under the terms and conditions of the GNU
 * General Public License (see file COPYING)
 */
using System;
using System.IO;
using System.Collections;
using System.Runtime.Serialization;
using System.Runtime.Serialization.Formatters.Binary;

namespace CCM {

public class BinDumper {
   public static int Main( string[] args ) {
       Model model;

       if( args.Length != 1 ) {
	   Console.WriteLine( "Usage: bindumper.exe <binfile>" );
	   return 0;
       }
       try {
	   FileStream fs = new FileStream( args[0], FileMode.Open );
	   model = new Model( fs );
	   fs.Close();
       }
       catch( SerializationException e ) {
	   Console.WriteLine( "Error: could not deserialize processes: " + e );
	   return -4;
       } catch( IOException e ) {
	   Console.WriteLine( "Error: could not open input file " + args[0] + ": " + e );
	   return -3;
       }
       Console.WriteLine( "Model deserialized" );

       model.writeCCMB( Console.Out );
       Console.WriteLine( model.stateAbstraction );
       return 0;
   }
}

}
